package com.ruoyi.mall.mapper;

import java.util.List;
import java.util.Map;

import com.ruoyi.mall.domain.MallCoupon;
import org.apache.ibatis.annotations.Param;

/**
 * 优惠券Mapper接口
 *
 * @author ruoyi
 * @date 2021-12-17
 */
public interface MallCouponMapper
{
    /**
     * 查询优惠券
     *
     * @param id 优惠券主键
     * @return 优惠券
     */
    public MallCoupon selectMallCouponById(Long id);

    /**
     * 查询优惠券列表
     *
     * @param mallCoupon 优惠券
     * @return 优惠券集合
     */
    public List<MallCoupon> selectMallCouponList(MallCoupon mallCoupon);

    /**
     * 新增优惠券
     *
     * @param mallCoupon 优惠券
     * @return 结果
     */
    public int insertMallCoupon(MallCoupon mallCoupon);

    /**
     * 修改优惠券
     *
     * @param mallCoupon 优惠券
     * @return 结果
     */
    public int updateMallCoupon(MallCoupon mallCoupon);

    /**
     * 删除优惠券
     *
     * @param id 优惠券主键
     * @return 结果
     */
    public int deleteMallCouponById(Long id);

    /**
     * 批量删除优惠券
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteMallCouponByIds(Long[] ids);

    public List<Map<String, Object>> selectMallCouponVOList(@Param("type") Integer type);

    /**
     * 兑换优惠券列表
     *
     * @param params userId 用户id
     * @return 结果
     */
    public List<Map<String, Object>> exchangeCouponList(Map<String, Object> params);
}
