package com.ruoyi.mall.controller;

import java.util.List;

import com.ruoyi.common.utils.DateUtils;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.mall.domain.MallCoupon;
import com.ruoyi.mall.service.IMallCouponService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 优惠券Controller
 * 
 * @author ruoyi
 * @date 2021-12-17
 */
@RestController
@RequestMapping("/mall/mallCoupon")
public class MallCouponController extends BaseController
{
    @Autowired
    private IMallCouponService mallCouponService;

    /**
     * 查询优惠券列表
     */
    @PreAuthorize("@ss.hasPermi('mall:mallCoupon:list')")
    @GetMapping("/list")
    public TableDataInfo list(MallCoupon mallCoupon)
    {
        startPage();
        List<MallCoupon> list = mallCouponService.selectMallCouponList(mallCoupon);
        return getDataTable(list);
    }

    /**
     * 导出优惠券列表
     */
    @PreAuthorize("@ss.hasPermi('mall:mallCoupon:export')")
    @Log(title = "优惠券", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(MallCoupon mallCoupon)
    {
        List<MallCoupon> list = mallCouponService.selectMallCouponList(mallCoupon);
        ExcelUtil<MallCoupon> util = new ExcelUtil<MallCoupon>(MallCoupon.class);
        return util.exportExcel(list, "优惠券数据");
    }

    /**
     * 获取优惠券详细信息
     */
    @PreAuthorize("@ss.hasPermi('mall:mallCoupon:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(mallCouponService.selectMallCouponById(id));
    }

    /**
     * 新增优惠券
     */
    @PreAuthorize("@ss.hasPermi('mall:mallCoupon:add')")
    @Log(title = "优惠券", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody MallCoupon mallCoupon)
    {
        if ("0".equals(mallCoupon.getType())){
            MallCoupon typeCoupon = new MallCoupon();
            typeCoupon.setType("0");
            List<MallCoupon> list = mallCouponService.selectMallCouponList(typeCoupon);
            if (list.size() > 0){
                return AjaxResult.error("新人优惠券已经存在，请前去修改");
            }
        }
        mallCoupon.setCreateAt(DateUtils.getTime());
        return toAjax(mallCouponService.insertMallCoupon(mallCoupon));
    }

    /**
     * 修改优惠券
     */
    @PreAuthorize("@ss.hasPermi('mall:mallCoupon:edit')")
    @Log(title = "优惠券", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody MallCoupon mallCoupon)
    {
        mallCoupon.setUpdateAt(DateUtils.getTime());
        return toAjax(mallCouponService.updateMallCoupon(mallCoupon));
    }

    /**
     * 删除优惠券
     */
    @PreAuthorize("@ss.hasPermi('mall:mallCoupon:remove')")
    @Log(title = "优惠券", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(mallCouponService.deleteMallCouponByIds(ids));
    }
}
